;+
; NAME:
;      hxi_unnorm
; PURPOSE:
;      Restores a byte-type cube of hxi images to floating pt.,
; CATEGORY:
;      Yohkoh HXT
; CALLING SEQUENCE:
;      d1 = hxi_unnorm(index, data, /dt_norm, /strip, /hxtpro)
; INPUT:
;      index = index structure for hxi images
;      data = data cube byte type
; OUTPUT:
;      d1 = for each image d1=data*index.hxi.max_bright/255.0
; KEYWORDS:
;      dt_norm = if set, will normalize by the accumulation time
;      strip = if set, strip the images to the size given
;              by index(0).hxi.shape_sav
;      hxtpro = if set, data is hxtpro output, normalized by
;               total counts instead of the max. brightness
; HISTORY:
;      10/13/94, jmm
;      9/21/95, jmjm, does nothing if a non-byte array is passed in,
;               unless the dt_norm keyword is set.
;      27/09/2000, rdb, changed typ to dtyp to avoind naoe collision
;-
FUNCTION Hxi_unnorm, index, data, dt_norm=dt_norm, strip=strip, hxtpro=hxtpro

; number of elements
   nexp = N_ELEMENTS(index)
   nexp1 = N_ELEMENTS(data(0, 0, *))
   IF(nexp1 NE nexp) THEN BEGIN
      print, 'Index and Data mis-match in HXI_UNNORM'
      RETURN, -1
   ENDIF

   dtyp = size(data) & dtyp = dtyp(dtyp(0)+1)
   
; This is easy
   IF(KEYWORD_SET(hxtpro)) THEN BEGIN
      dt = index.hxi.actim/10.0
      c = fltarr(nexp)
      FOR j = 0, nexp-1 DO BEGIN
         IF(KEYWORD_SET(dt_norm)) THEN BEGIN
            IF(dtyp EQ 1) THEN c(j) = index(j).hxi.cnts_p_cm2/(total(data(*, *, j))*dt(j)) $
              ELSE c(j) = 1.0/dt(j)
         ENDIF ELSE BEGIN
            IF(dtyp EQ 1) THEN c(j) = index(j).hxi.cnts_p_cm2/(total(data(*, *, j))) $
              ELSE c(j) = 1.0
         ENDELSE
      ENDFOR
   ENDIF ELSE BEGIN
      IF(KEYWORD_SET(dt_norm)) THEN BEGIN ;remember actim is in 10ths of seconds
         IF(dtyp EQ 1) THEN c = index.hxi.max_bright/(25.5*index.hxi.actim) $
           ELSE c = 10.0/index.hxi.actim
      ENDIF ELSE BEGIN
         IF(dtyp EQ 1) THEN c = index.hxi.max_bright/255.0 ELSE c = fltarr(nexp)+1.0
      ENDELSE
   ENDELSE
   
   IF(KEYWORD_SET(strip)) THEN BEGIN
      ipix = index(0).hxi.shape_sav(0)
      jpix = index(0).hxi.shape_sav(1)
      d1 = float(data(0:ipix-1, 0:jpix-1, *))
   ENDIF ELSE d1 = float(data)

   FOR j = 0, nexp-1 DO d1(*, *, j) = d1(*, *, j)*c(j)   

   RETURN, d1
END
